@@ -17,8 +17,7 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#ifndef __ATK_OBJECT_H__
-#define __ATK_OBJECT_H__
+#pragma once
 
 #if defined(ATK_DISABLE_SINGLE_INCLUDES) && !defined(__ATK_H_INSIDE__) && !defined(ATK_COMPILATION)
 #error "Only <atk/atk.h> can be included directly."
@@ -76,7 +75,7 @@ G_BEGIN_DECLS
  *@ATK_ROLE_PASSWORD_TEXT: A text object uses for passwords, or other places where the text content is not shown visibly to the user
  *@ATK_ROLE_POPUP_MENU: A temporary window that is usually used to offer the user a list of choices, and then hides when the user selects one of those choices
  *@ATK_ROLE_PROGRESS_BAR: An object used to indicate how much of a task has been completed
- *@ATK_ROLE_PUSH_BUTTON: An object the user can manipulate to tell the application to do something
+ *@ATK_ROLE_BUTTON: An object the user can manipulate to tell the application to do something
  *@ATK_ROLE_RADIO_BUTTON: A specialized check box that will cause other radio buttons in the same group to become unchecked when this one is checked
  *@ATK_ROLE_RADIO_MENU_ITEM: A check menu item which belongs to a group. At each instant exactly one of the radio menu items from a group is selected
  *@ATK_ROLE_ROOT_PANE: A specialized pane that has a glass pane and a layered pane as its children
@@ -93,7 +92,6 @@ G_BEGIN_DECLS
  *@ATK_ROLE_TABLE_COLUMN_HEADER: The header for a column of a table
  *@ATK_ROLE_TABLE_ROW_HEADER: The header for a row of a table
  *@ATK_ROLE_TEAR_OFF_MENU_ITEM: A menu item used to tear off and reattach its menu
- *@ATK_ROLE_TERMINAL: An object that represents an accessible terminal.  (Since: 0.6)
  *@ATK_ROLE_TEXT: An interactive widget that supports multiple lines of text and
  * optionally accepts user input, but whose purpose is not to solicit user input.
  * Thus ATK_ROLE_TEXT is appropriate for the text view in a plain text editor
@@ -105,98 +103,428 @@ G_BEGIN_DECLS
  *@ATK_ROLE_TOOL_BAR: A bar or palette usually composed of push buttons or toggle buttons
  *@ATK_ROLE_TOOL_TIP: An object that provides information about another object
  *@ATK_ROLE_TREE: An object used to represent hierarchical information to the user
- *@ATK_ROLE_TREE_TABLE: An object capable of expanding and collapsing rows as well as showing multiple columns of data.   (Since: 0.7)
  *@ATK_ROLE_UNKNOWN: The object contains some Accessible information, but its role is not known
  *@ATK_ROLE_VIEWPORT: An object usually used in a scroll pane
  *@ATK_ROLE_WINDOW: A top level window with no title or border.
- *@ATK_ROLE_HEADER: An object that serves as a document header. (Since: 1.1.1)
- *@ATK_ROLE_FOOTER: An object that serves as a document footer.  (Since: 1.1.1)
- *@ATK_ROLE_PARAGRAPH: An object which is contains a paragraph of text content.   (Since: 1.1.1)
- *@ATK_ROLE_RULER: An object which describes margins and tab stops, etc. for text objects which it controls (should have CONTROLLER_FOR relation to such).   (Since: 1.1.1)
- *@ATK_ROLE_APPLICATION: The object is an application object, which may contain @ATK_ROLE_FRAME objects or other types of accessibles.  The root accessible of any application's ATK hierarchy should have ATK_ROLE_APPLICATION.   (Since: 1.1.4)
- *@ATK_ROLE_AUTOCOMPLETE: The object is a dialog or list containing items for insertion into an entry widget, for instance a list of words for completion of a text entry.   (Since: 1.3)
- *@ATK_ROLE_EDITBAR: The object is an editable text object in a toolbar.  (Since: 1.5)
- *@ATK_ROLE_EMBEDDED: The object is an embedded container within a document or panel.  This role is a grouping "hint" indicating that the contained objects share a context.  (Since: 1.7.2)
- *@ATK_ROLE_ENTRY: The object is a component whose textual content may be entered or modified by the user, provided @ATK_STATE_EDITABLE is present.   (Since: 1.11)
- *@ATK_ROLE_CHART: The object is a graphical depiction of quantitative data. It may contain multiple subelements whose attributes and/or description may be queried to obtain both the quantitative data and information about how the data is being presented. The LABELLED_BY relation is particularly important in interpreting objects of this type, as is the accessible-description property.  (Since: 1.11)
- *@ATK_ROLE_CAPTION: The object contains descriptive information, usually textual, about another user interface element such as a table, chart, or image.  (Since: 1.11)
- *@ATK_ROLE_DOCUMENT_FRAME: The object is a visual frame or container which contains a view of document content. Document frames may occur within another Document instance, in which case the second document may be said to be embedded in the containing instance. HTML frames are often ROLE_DOCUMENT_FRAME. Either this object, or a singleton descendant, should implement the Document interface.  (Since: 1.11)
- *@ATK_ROLE_HEADING: The object serves as a heading for content which follows it in a document. The 'heading level' of the heading, if availabe, may be obtained by querying the object's attributes.
- *@ATK_ROLE_PAGE: The object is a containing instance which encapsulates a page of information. @ATK_ROLE_PAGE is used in documents and content which support a paginated navigation model.  (Since: 1.11)
- *@ATK_ROLE_SECTION: The object is a containing instance of document content which constitutes a particular 'logical' section of the document. The type of content within a section, and the nature of the section division itself, may be obtained by querying the object's attributes. Sections may be nested. (Since: 1.11)
- *@ATK_ROLE_REDUNDANT_OBJECT: The object is redundant with another object in the hierarchy, and is exposed for purely technical reasons.  Objects of this role should normally be ignored by clients. (Since: 1.11)
- *@ATK_ROLE_FORM: The object is a container for form controls, for instance as part of a
- * web form or user-input form within a document.  This role is primarily a tag/convenience for
- * clients when navigating complex documents, it is not expected that ordinary GUI containers will
- * always have ATK_ROLE_FORM. (Since: 1.12.0)
- *@ATK_ROLE_LINK: The object is a hypertext anchor, i.e. a "link" in a
- * hypertext document.  Such objects are distinct from 'inline'
- * content which may also use the Hypertext/Hyperlink interfaces
- * to indicate the range/location within a text object where
- * an inline or embedded object lies.  (Since: 1.12.1)
- *@ATK_ROLE_INPUT_METHOD_WINDOW: The object is a window or similar viewport
- * which is used to allow composition or input of a 'complex character',
- * in other words it is an "input method window." (Since: 1.12.1)
- *@ATK_ROLE_TABLE_ROW: A row in a table.  (Since: 2.1.0)
- *@ATK_ROLE_TREE_ITEM: An object that represents an element of a tree.  (Since: 2.1.0)
- *@ATK_ROLE_DOCUMENT_SPREADSHEET: A document frame which contains a spreadsheet.  (Since: 2.1.0)
- *@ATK_ROLE_DOCUMENT_PRESENTATION: A document frame which contains a presentation or slide content.  (Since: 2.1.0)
- *@ATK_ROLE_DOCUMENT_TEXT: A document frame which contains textual content, such as found in a word processing application.  (Since: 2.1.0)
- *@ATK_ROLE_DOCUMENT_WEB: A document frame which contains HTML or other markup suitable for display in a web browser.  (Since: 2.1.0)
- *@ATK_ROLE_DOCUMENT_EMAIL: A document frame which contains email content to be displayed or composed either in plain text or HTML.  (Since: 2.1.0)
- *@ATK_ROLE_COMMENT: An object found within a document and designed to present a comment, note, or other annotation. In some cases, this object might not be visible until activated.  (Since: 2.1.0)
- *@ATK_ROLE_LIST_BOX: A non-collapsible list of choices the user can select from. (Since: 2.1.0)
- *@ATK_ROLE_GROUPING: A group of related widgets. This group typically has a label. (Since: 2.1.0)
- *@ATK_ROLE_IMAGE_MAP: An image map object. Usually a graphic with multiple hotspots, where each hotspot can be activated resulting in the loading of another document or section of a document. (Since: 2.1.0)
- *@ATK_ROLE_NOTIFICATION: A transitory object designed to present a message to the user, typically at the desktop level rather than inside a particular application.  (Since: 2.1.0)
- *@ATK_ROLE_INFO_BAR: An object designed to present a message to the user within an existing window. (Since: 2.1.0)
- *@ATK_ROLE_LEVEL_BAR: A bar that serves as a level indicator to, for instance, show the strength of a password or the state of a battery.  (Since: 2.7.3)
- *@ATK_ROLE_TITLE_BAR: A bar that serves as the title of a window or a
- * dialog. (Since: 2.12)
- *@ATK_ROLE_BLOCK_QUOTE: An object which contains a text section
- * that is quoted from another source. (Since: 2.12)
- *@ATK_ROLE_AUDIO: An object which represents an audio element. (Since: 2.12)
- *@ATK_ROLE_VIDEO: An object which represents a video element. (Since: 2.12)
- *@ATK_ROLE_DEFINITION: A definition of a term or concept. (Since: 2.12)
- *@ATK_ROLE_ARTICLE: A section of a page that consists of a
- * composition that forms an independent part of a document, page, or
- * site. Examples: A blog entry, a news story, a forum post. (Since: 2.12)
- *@ATK_ROLE_LANDMARK: A region of a web page intended as a
- * navigational landmark. This is designed to allow Assistive
- * Technologies to provide quick navigation among key regions within a
- * document. (Since: 2.12)
- *@ATK_ROLE_LOG: A text widget or container holding log content, such
- * as chat history and error logs. In this role there is a
- * relationship between the arrival of new items in the log and the
- * reading order. The log contains a meaningful sequence and new
- * information is added only to the end of the log, not at arbitrary
- * points. (Since: 2.12)
- *@ATK_ROLE_MARQUEE: A container where non-essential information
- * changes frequently. Common usages of marquee include stock tickers
- * and ad banners. The primary difference between a marquee and a log
- * is that logs usually have a meaningful order or sequence of
- * important content changes. (Since: 2.12)
- *@ATK_ROLE_MATH: A text widget or container that holds a mathematical
- * expression. (Since: 2.12)
- *@ATK_ROLE_RATING: A widget whose purpose is to display a rating,
- * such as the number of stars associated with a song in a media
- * player. Objects of this role should also implement
- * AtkValue. (Since: 2.12)
- *@ATK_ROLE_TIMER: An object containing a numerical counter which
- * indicates an amount of elapsed time from a start point, or the time
- * remaining until an end point. (Since: 2.12)
- *@ATK_ROLE_DESCRIPTION_LIST: An object that represents a list of
- * term-value groups. A term-value group represents a individual
- * description and consist of one or more names
+ *@ATK_ROLE_HEADING: The object serves as a heading for content which follows it in a document. The 'heading level' of the heading, if available, may be obtained by querying the object's attributes.
+ *@ATK_ROLE_LAST_DEFINED: not a valid role, used for finding end of the enumeration
+ *
+ * Describes the role of an object
+ *
+ * These are the built-in enumerated roles that UI components can have
+ * in ATK.  Other roles may be added at runtime, so an AtkRole >=
+ * %ATK_ROLE_LAST_DEFINED is not necessarily an error.
+ */
+
+/**
+ * ATK_ROLE_TERMINAL:
+ *
+ *  An object that represents an accessible terminal.
+ * Since: 0.6
+ */
+
+/**
+ * ATK_ROLE_TREE_TABLE:
+ *
+ *  An object capable of expanding and collapsing rows as well as showing
+ * multiple columns of data.
+ * Since: 0.7
+ */
+
+/**
+ * ATK_ROLE_HEADER:
+ *
+ *  An object that serves as a document header.
+ * Since: 1.1.1
+ */
+
+/**
+ * ATK_ROLE_FOOTER:
+ *
+ *  An object that serves as a document footer.
+ * Since: 1.1.1
+ */
+
+/**
+ * ATK_ROLE_PARAGRAPH:
+ *
+ *  An object which contains a paragraph of text content.
+ * Since: 1.1.1
+ */
+
+/**
+ * ATK_ROLE_RULER:
+ *
+ *  An object which describes margins and tab stops, etc. for text objects
+ * which it controls (should have CONTROLLER_FOR relation to such).
+ * Since: 1.1.1
+ */
+
+/**
+ * ATK_ROLE_APPLICATION:
+ *
+ *  The object is an application object, which may contain @ATK_ROLE_FRAME
+ * objects or other types of accessibles.  The root accessible of any
+ * application's ATK hierarchy should have ATK_ROLE_APPLICATION.
+ * Since: 1.1.4
+ */
+
+/**
+ * ATK_ROLE_AUTOCOMPLETE:
+ *
+ *  The object is a dialog or list containing items for insertion into an entry
+ * widget, for instance a list of words for completion of a text entry.
+ * Since: 1.3
+ */
+
+/**
+ * ATK_ROLE_EDITBAR:
+ *
+ *  The object is an editable text object in a toolbar.
+ * Since: 1.5
+ */
+
+/**
+ * ATK_ROLE_EMBEDDED:
+ *
+ *  The object is an embedded container within a document or panel.  This role
+ * is a grouping "hint" indicating that the contained objects share a context.
+ *
+ * Since: 1.7.2
+ */
+
+/**
+ * ATK_ROLE_ENTRY:
+ *
+ *  The object is a component whose textual content may be entered or modified
+ * by the user, provided @ATK_STATE_EDITABLE is present.
+ * Since: 1.11
+ */
+
+/**
+ * ATK_ROLE_CHART:
+ *
+ *  The object is a graphical depiction of quantitative data. It may contain
+ * multiple subelements whose attributes and/or description may be queried to
+ * obtain both the quantitative data and information about how the data is
+ * being presented. The LABELLED_BY relation is particularly important in
+ * interpreting objects of this type, as is the accessible-description
+ * property.
+ * Since: 1.11
+ */
+
+/**
+ * ATK_ROLE_CAPTION:
+ *
+ *  The object contains descriptive information, usually textual, about another
+ * user interface element such as a table, chart, or image.
+ * Since: 1.11
+ */
+
+/**
+ * ATK_ROLE_DOCUMENT_FRAME:
+ *
+ *  The object is a visual frame or container which contains a view of document
+ * content. Document frames may occur within another Document instance, in
+ * which case the second document may be said to be embedded in the containing
+ * instance. HTML frames are often ROLE_DOCUMENT_FRAME. Either this object, or
+ * a singleton descendant, should implement the Document interface.
+ * Since: 1.11
+ */
+
+/**
+ * ATK_ROLE_PAGE:
+ *
+ *  The object is a containing instance which encapsulates a page of
+ * information. @ATK_ROLE_PAGE is used in documents and content which support a
+ * paginated navigation model.
+ * Since: 1.11
+ */
+
+/**
+ * ATK_ROLE_SECTION:
+ *
+ *  The object is a containing instance of document content which constitutes a
+ * particular 'logical' section of the document. The type of content within a
+ * section, and the nature of the section division itself, may be obtained by
+ * querying the object's attributes. Sections may be nested.
+ * Since: 1.11
+ */
+
+/**
+ * ATK_ROLE_REDUNDANT_OBJECT:
+ *
+ *  The object is redundant with another object in the hierarchy, and is
+ * exposed for purely technical reasons.  Objects of this role should normally
+ * be ignored by clients.
+ * Since: 1.11
+ */
+
+/**
+ * ATK_ROLE_FORM:
+ *
+ *  The object is a container for form controls, for instance as part of a web
+ * form or user-input form within a document.  This role is primarily a
+ * tag/convenience for clients when navigating complex documents, it is not
+ * expected that ordinary GUI containers will always have ATK_ROLE_FORM.
+ * Since: 1.12.0
+ */
+
+/**
+ * ATK_ROLE_LINK:
+ *
+ *  The object is a hypertext anchor, i.e. a "link" in a hypertext document.
+ * Such objects are distinct from 'inline' content which may also use the
+ * Hypertext/Hyperlink interfaces to indicate the range/location within a text
+ * object where an inline or embedded object lies.
+ * Since: 1.12.1
+ */
+
+/**
+ * ATK_ROLE_INPUT_METHOD_WINDOW:
+ *
+ *  The object is a window or similar viewport which is used to allow
+ * composition or input of a 'complex character', in other words it is an
+ * "input method window."
+ * Since: 1.12.1
+ */
+
+/**
+ * ATK_ROLE_TABLE_ROW:
+ *
+ *  A row in a table.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_TREE_ITEM:
+ *
+ *  An object that represents an element of a tree.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_DOCUMENT_SPREADSHEET:
+ *
+ *  A document frame which contains a spreadsheet.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_DOCUMENT_PRESENTATION:
+ *
+ *  A document frame which contains a presentation or slide content.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_DOCUMENT_TEXT:
+ *
+ *  A document frame which contains textual content, such as found in a word
+ * processing application.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_DOCUMENT_WEB:
+ *
+ *  A document frame which contains HTML or other markup suitable for display
+ * in a web browser.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_DOCUMENT_EMAIL:
+ *
+ *  A document frame which contains email content to be displayed or composed
+ * either in plain text or HTML.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_COMMENT:
+ *
+ *  An object found within a document and designed to present a comment, note,
+ * or other annotation. In some cases, this object might not be visible until
+ * activated.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_LIST_BOX:
+ *
+ * A non-collapsible list of choices the user can select from.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_GROUPING:
+ *
+ * A group of related widgets. This group typically has a label.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_IMAGE_MAP:
+ *
+ * An image map object. Usually a graphic with multiple hotspots, where
+ * each hotspot can be activated resulting in the loading of another
+ * document or section of a document.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_NOTIFICATION:
+ *
+ * A transitory object designed to present a message to the user, typically
+ * at the desktop level rather than inside a particular application.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_INFO_BAR:
+ *
+ * An object designed to present a message to the user within an existing
+ * window.
+ * Since: 2.1.0
+ */
+
+/**
+ * ATK_ROLE_LEVEL_BAR:
+ *
+ * A bar that serves as a level indicator to, for instance, show the strength of a
+ * password or the state of a battery.
+ * Since: 2.7.3
+ */
+
+/**
+ * ATK_ROLE_TITLE_BAR:
+ *
+ * A bar that serves as the title of a window or a dialog.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_BLOCK_QUOTE:
+ *
+ * An object which contains a text section that is quoted from another source.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_AUDIO:
+ *
+ * An object which represents an audio element.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_VIDEO:
+ *
+ * An object which represents a video element.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_DEFINITION:
+ *
+ * A definition of a term or concept.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_ARTICLE:
+ *
+ * A section of a page that consists of a composition that forms an independent
+ * part of a document, page, or site. Examples: A blog entry, a news story,
+ * a forum post.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_LANDMARK:
+ *
+ * A region of a web page intended as a * navigational landmark. This is
+ * designed to allow Assistive Technologies to provide quick navigation
+ * among key regions within a * document.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_LOG:
+ *
+ * A text widget or container holding log content, such as chat history
+ * and error logs. In this role there is a relationship between the arrival
+ * of new items in the log and the reading order. The log contains a
+ * meaningful sequence and new information is added only to the end of
+ * the log, not at arbitrary points.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_MARQUEE:
+ *
+ * A container where non-essential information changes frequently. Common
+ * usages of marquee include stock tickers * and ad banners. The primary
+ * difference between a marquee and a log is that logs usually have a
+ * meaningful order or sequence of important content changes.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_MATH:
+ *
+ * A text widget or container that holds a mathematical expression.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_RATING:
+ *
+ * A widget whose purpose is to display a rating, such as the number of
+ * stars associated with a song in a media player. Objects of this role should
+ * also implement AtkValue.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_TIMER:
+ *
+ * An object containing a numerical counter which indicates an amount of
+ * elapsed time from a start point, or the time remaining until an end point.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_DESCRIPTION_LIST:
+ *
+ * An object that represents a list of term-value groups. A term-value group
+ * represents an individual description and consist of one or more names
  * (ATK_ROLE_DESCRIPTION_TERM) followed by one or more values
  * (ATK_ROLE_DESCRIPTION_VALUE). For each list, there should not be
- * more than one group with the same term name. (Since: 2.12)
- *@ATK_ROLE_DESCRIPTION_TERM: An object that represents a term or phrase
- * with a corresponding definition. (Since: 2.12)
- *@ATK_ROLE_DESCRIPTION_VALUE: An object that represents the
- * description, definition or value of a term. (Since: 2.12)
- *@ATK_ROLE_STATIC: A generic non-container object whose purpose is to display a
- * brief amount of information to the user and whose role is known by the
+ * more than one group with the same term name.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_DESCRIPTION_TERM:
+ *
+ * An object that represents a term or phrase with a corresponding definition.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_DESCRIPTION_VALUE:
+ *
+ * An object that represents the description, definition or value of a term.
+ * Since: 2.12
+ */
+
+/**
+ * ATK_ROLE_STATIC:
+ *
+ * A generic non-container object whose purpose is to display a brief
+ * amount of information to the user and whose role is known by the
  * implementor but lacks semantic value for the user. Examples in which
  * %ATK_ROLE_STATIC is appropriate include the message displayed in a message box
  * and an image used as an alternative means to display text. %ATK_ROLE_STATIC
@@ -207,43 +535,100 @@ G_BEGIN_DECLS
  * inappropriate, it may indicate that a different role should be used. For
  * labels which describe another widget, see %ATK_ROLE_LABEL. For text views, see
  * %ATK_ROLE_TEXT. For generic containers, see %ATK_ROLE_PANEL. For objects whose
- * role is not known by the implementor, see %ATK_ROLE_UNKNOWN. (Since: 2.16)
- *@ATK_ROLE_MATH_FRACTION: An object that represents a mathematical fraction.
- * (Since: 2.16)
- *@ATK_ROLE_MATH_ROOT: An object that represents a mathematical expression
- * displayed with a radical. (Since: 2.16)
- *@ATK_ROLE_SUBSCRIPT: An object that contains text that is displayed as a
- * subscript. (Since: 2.16)
- *@ATK_ROLE_SUPERSCRIPT: An object that contains text that is displayed as a
- * superscript. (Since: 2.16)
- *@ATK_ROLE_FOOTNOTE: An object that contains the text of a footnote. (Since: 2.26)
- *@ATK_ROLE_CONTENT_DELETION: Content previously deleted or proposed to be
- * deleted, e.g. in revision history or a content view providing suggestions
- * from reviewers. (Since: 2.34)
- *@ATK_ROLE_CONTENT_INSERTION: Content previously inserted or proposed to be
- * inserted, e.g. in revision history or a content view providing suggestions
- * from reviewers. (Since: 2.34)
- *@ATK_ROLE_MARK: A run of content that is marked or highlighted, such as for
- * reference purposes, or to call it out as having a special purpose. If the
- * marked content has an associated section in the document elaborating on the
+ * role is not known by the implementor, see %ATK_ROLE_UNKNOWN.
+ * Since: 2.16
+ */
+
+/**
+ * ATK_ROLE_MATH_FRACTION:
+ *
+ * An object that represents a mathematical fraction.
+ * Since: 2.16
+ */
+
+/**
+ * ATK_ROLE_MATH_ROOT:
+ *
+ * An object that represents a mathematical expression displayed with a
+ * radical.
+ *
+ * Since: 2.16
+ */
+
+/**
+ * ATK_ROLE_SUBSCRIPT:
+ *
+ * An object that contains text that is displayed as a subscript.
+ * Since: 2.16
+ */
+
+/**
+ * ATK_ROLE_SUPERSCRIPT:
+ *
+ * An object that contains text that is displayed as a superscript.
+ * Since: 2.16
+ */
+
+/**
+ * ATK_ROLE_FOOTNOTE:
+ *
+ * An object that contains the text of a footnote.
+ *
+ * Since: 2.26
+ */
+
+/**
+ * ATK_ROLE_CONTENT_DELETION:
+ *
+ * Content previously deleted or proposed to be deleted, e.g. in revision
+ * history or a content view providing suggestions from reviewers.
+ * Since: 2.34
+ */
+
+/**
+ * ATK_ROLE_CONTENT_INSERTION:
+ *
+ * Content previously inserted or proposed to be inserted, e.g. in revision
+ * history or a content view providing suggestions from reviewers.
+ * Since: 2.34
+ */
+
+/**
+ * ATK_ROLE_MARK
+ *
+ * A run of content that is marked or highlighted, such as for reference
+ *  purposes, or to call it out as having a special purpose. If the marked
+ * content has an associated section in the document elaborating on the
  * reason for the mark, then %ATK_RELATION_DETAILS should be used on the mark
  * to point to that associated section. In addition, the reciprocal relation
  * %ATK_RELATION_DETAILS_FOR should be used on the associated content section
- * to point back to the mark. (Since: 2.36)
- *@ATK_ROLE_SUGGESTION: A container for content that is called out as a proposed
- * change from the current version of the document, such as by a reviewer of the
+ * to point back to the mark.
+ * Since: 2.36
+ */
+
+/**
+ * ATK_ROLE_SUGGESTION:
+ *
+ * A container for content that is called out as a proposed change from
+ * the current version of the document, such as by a reviewer of the
  * content. This role should include either %ATK_ROLE_CONTENT_DELETION and/or
  * %ATK_ROLE_CONTENT_INSERTION children, in any order, to indicate what the
- * actual change is. (Since: 2.36)
- *@ATK_ROLE_PUSH_BUTTON_MENU: A specialized push button to open a menu.
- * (Since: 2.46)
- *@ATK_ROLE_LAST_DEFINED: not a valid role, used for finding end of the enumeration
+ * actual change is.
+ * Since: 2.36
+ */
+
+/**
+ * ATK_ROLE_PUSH_BUTTON_MENU:
  *
- * Describes the role of an object
+ * A specialized push button to open a menu.
+ * Since: 2.46
+ */
+
+/**
+ * ATK_ROLE_SWITCH:
  *
- * These are the built-in enumerated roles that UI components can have
- * in ATK.  Other roles may be added at runtime, so an AtkRole >=
- * %ATK_ROLE_LAST_DEFINED is not necessarily an error.
+ * A switch that can be toggled on/off.
+ * Since: 2.56
  */
 typedef enum
 {
@@ -289,7 +674,7 @@ typedef enum
   ATK_ROLE_PASSWORD_TEXT,
   ATK_ROLE_POPUP_MENU,
   ATK_ROLE_PROGRESS_BAR,
-  ATK_ROLE_PUSH_BUTTON,
+  ATK_ROLE_BUTTON,
   ATK_ROLE_RADIO_BUTTON,
   ATK_ROLE_RADIO_MENU_ITEM,
   ATK_ROLE_ROOT_PANE,
@@ -375,7 +760,11 @@ typedef enum
   ATK_ROLE_MARK,
   ATK_ROLE_SUGGESTION,
   ATK_ROLE_PUSH_BUTTON_MENU,
-  ATK_ROLE_LAST_DEFINED
+  ATK_ROLE_SWITCH,
+  ATK_ROLE_LAST_DEFINED,
+
+  /* For backwards compatibility */
+  ATK_ROLE_PUSH_BUTTON = ATK_ROLE_BUTTON,
 } AtkRole;
 
 /**
@@ -820,5 +1209,3 @@ void atk_object_set_help_text (AtkObject *accessible,
                                const gchar *help_text);
 
 G_END_DECLS
-
-#endif /* __ATK_OBJECT_H__ */
